pointcloudutils update {#master}
-------------------------------

## Libraries

### `sig`

* now yarp::sig::utils::depthRgbToPC has an additional optional parameter to make the pointcloud unorganized
* and remove zero points
